==> ecomero-erpcore-1.0.39.zip: Service/ExportOrderService.php <==
<?php declare(strict_types=1);
/**
 *
 *           a88888P8
 *          d8'
 * .d8888b. 88        .d8888b. 88d8b.d8b. .d8888b. .dd888b. .d8888b.
 * 88ooood8 88        88'  `88 88'`88'`88 88ooood8 88'    ` 88'  `88
 * 88.  ... Y8.       88.  .88 88  88  88 88.  ... 88       88.  .88
 * `8888P'   Y88888P8 `88888P' dP  dP  dP `8888P'  dP       `88888P'
 *
 *           Copyright © eComero Management AB, All rights reserved.
 *
 */
namespace Ecomero\ErpCore\Service;

use Ecomero\ErpCore\Helper\ErpLogger;
use Ecomero\ErpCore\Helper\Notification;
use Ecomero\ErpCore\Helper\Settings;
use Ecomero\ErpCore\Helper\TaxItemHelper;
use Ecomero\ErpCore\Model\Capability;
use Ecomero\ErpCore\Model\ErpAdapterInterface;

use Magento\Sales\Api\OrderRepositoryInterface;
use Magento\Sales\Model\ResourceModel\Order\CollectionFactory;

class ExportOrderService extends OrderServiceAbstract
{
    protected $productService;
    protected $taxItemHelper;

    public function __construct(
        ErpLogger $logger,
        Notification $notification,
        ErpAdapterInterface $erp,
        Settings $settings,
        CustomerService $customerService,
        CollectionFactory $orderCollectionFactory,
        OrderRepositoryInterface $orderRepository,
        ProductService $productService,
        TaxItemHelper $taxItemHelper
    ) {
        parent::__construct(
            $logger,
            $notification,
            $settings,
            $erp,
            $customerService,
            $orderCollectionFactory,
            $orderRepository
        );

        $this->productService = $productService;
        $this->taxItemHelper = $taxItemHelper;
    }

    protected function getServiceDescription() : string
    {
        return 'order export';
    }

    protected function getDocumentType() : string
    {
        return 'Order';
    }

    protected function getCapability() : string
    {
        return Capability::ORDER_EXPORT;
    }

    protected function getOrderStatusFilter() : string
    {
        return $this->settings->getOrderStatusSend();
    }

    protected function processOrder(object $order) : void
    {
        if ($this->isDocumentAlreadyInErp($order['increment_id'])) {
            return;
        }

        $orderResponse = $this->createNewDocument(
            $order,
            $order['order_currency_code']
        );

        $numOrderLines = $this->addDocumentLines($order, $orderResponse, $order['entity_id']);

        $this->addShippingCharges($order, $orderResponse, $order['entity_id'], $numOrderLines);

        // Update order number to "tag" order as completely transferred
        $orderResponse = $this->erp->updateDocument(
            $this->getDocumentType(),
            $orderResponse->id,
            $order['increment_id']
        );

        $orderStatusMarkSent = $this->settings->getOrderStatusSent();
        $order->setStatus($orderStatusMarkSent);
        $order->setState(\Magento\Sales\Model\Order::STATE_PROCESSING);

        $order->addStatusToHistory(
            $orderStatusMarkSent,
            $this->getDocumentType() . ' sucessfully transferred to Erp with id ' . $orderResponse->number
        );
        $order->setErpOrderNo($orderResponse->number);
        $order->setErpCustomerNo($orderResponse->customerNumber);
        $order->save();
    }
}

==> ecomero-erpcore-1.0.54.zip: Service/ExportOrderService.php <==
<?php declare(strict_types=1);
/**
 *
 *           a88888P8
 *          d8'
 * .d8888b. 88        .d8888b. 88d8b.d8b. .d8888b. .dd888b. .d8888b.
 * 88ooood8 88        88'  `88 88'`88'`88 88ooood8 88'    ` 88'  `88
 * 88.  ... Y8.       88.  .88 88  88  88 88.  ... 88       88.  .88
 * `8888P'   Y88888P8 `88888P' dP  dP  dP `8888P'  dP       `88888P'
 *
 *           Copyright © eComero Management AB, All rights reserved.
 *
 */
namespace Ecomero\ErpCore\Service;

use Ecomero\ErpCore\Helper\ErpLogger;
use Ecomero\ErpCore\Helper\Notification;
use Ecomero\ErpCore\Helper\Settings;
use Ecomero\ErpCore\Helper\TaxItemHelper;
use Ecomero\ErpCore\Model\Capability;
use Ecomero\ErpCore\Model\ErpAdapterInterface;

use Magento\Sales\Api\OrderRepositoryInterface;
use Magento\Sales\Model\ResourceModel\Order\CollectionFactory;

class ExportOrderService extends OrderServiceAbstract
{
    protected $productService;
    protected $taxItemHelper;

    public function __construct(
        ErpLogger $logger,
        Notification $notification,
        ErpAdapterInterface $erp,
        Settings $settings,
        CustomerService $customerService,
        CollectionFactory $orderCollectionFactory,
        OrderRepositoryInterface $orderRepository,
        ProductService $productService,
        TaxItemHelper $taxItemHelper
    ) {
        parent::__construct(
            $logger,
            $notification,
            $settings,
            $erp,
            $customerService,
            $orderCollectionFactory,
            $orderRepository
        );

        $this->productService = $productService;
        $this->taxItemHelper = $taxItemHelper;
    }

    protected function getServiceDescription() : string
    {
        return 'order export';
    }

    protected function getDocumentType() : string
    {
        return 'Order';
    }

    protected function getCapability() : string
    {
        return Capability::ORDER_EXPORT;
    }

    protected function getOrderStatusFilter() : string
    {
        return $this->settings->getOrderStatusSend();
    }

    protected function processOrder(object $order) : void
    {
        if ($this->isDocumentAlreadyInErp($order['increment_id'])) {
            return;
        }

        // Check if we already got an order number, then never export
        if ($order['erp_order_no'] && $order['erp_order_no'] !== OrderServiceAbstract::ERROR_MARKER) {
            $this->logger->error('Found existing order number, can not export again ' . $order['erp_order_no']);
            return;
        }

        $orderResponse = $this->createNewDocument(
            $order,
            $order['order_currency_code']
        );

        $numOrderLines = $this->addDocumentLines($order, $orderResponse, $order['entity_id']);

        $this->addShippingCharges($order, $orderResponse, $order['entity_id'], $numOrderLines);

        // Update order number to "tag" order as completely transferred
        $orderResponse = $this->erp->updateDocument(
            $this->getDocumentType(),
            $orderResponse->id,
            $order['increment_id']
        );

        $orderStatusMarkSent = $this->settings->getOrderStatusSent();
        $order->setStatus($orderStatusMarkSent);
        $order->setState(\Magento\Sales\Model\Order::STATE_PROCESSING);

        $order->addStatusToHistory(
            $orderStatusMarkSent,
            $this->getDocumentType() . ' sucessfully transferred to Erp with id ' . $orderResponse->number
        );
        $order->setErpOrderNo($orderResponse->number);
        $order->setErpCustomerNo($orderResponse->customerNumber);
        $order->save();
    }
}
